"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const graphql_codegen_hasura_shared_1 = require("graphql-codegen-hasura-shared");
exports.plugin = (schema, documents, config) => {
    // Set config defaults
    if (config.reactApolloVersion && config.reactApolloVersion !== 3) {
        throw new Error("Currently this codegen tool is only compatible with Apollo Client V3");
    }
    const contentManager = new graphql_codegen_hasura_shared_1.ContentManager();
    graphql_codegen_hasura_shared_1.injectGlobalReactCode({
        contentManager,
        typescriptCodegenOutputPath: config.typescriptCodegenOutputPath,
        withUpdates: config.withUpdates
    });
    // get typemap from schema
    const typeMap = schema.getTypeMap();
    // find fragment documents
    const documentFragments = documents.flatMap(document => {
        return document.content.definitions.filter(definition => definition.kind === "FragmentDefinition");
    });
    // iterate and generate
    documentFragments.map(fragmentDefinition => {
        injectEntitySharedTypeScript(fragmentDefinition, contentManager, typeMap, config);
        config.withQueries && injectEntityQueryTypeScript(fragmentDefinition, contentManager, typeMap, config);
        config.withInserts && injectEntityInsertMutationTypeScript(fragmentDefinition, contentManager, typeMap, config);
        config.withUpdates && injectEntityUpdateMutationTypeScript(fragmentDefinition, contentManager, typeMap, config);
        config.withDeletes && injectEntityDeleteMutationTypeScript(fragmentDefinition, contentManager, typeMap, config);
    });
    return {
        prepend: contentManager.generateImportArray(),
        content: contentManager.createContentString()
    };
};
// --------------------------------------
//
function injectEntitySharedTypeScript(fragmentDefinitionNode, contentManager, schemaTypeMap, config) {
    const fragmentName = fragmentDefinitionNode.name.value;
    const fragmentTableName = fragmentDefinitionNode.typeCondition.name.value;
    const relatedTableNamedType = schemaTypeMap[fragmentTableName];
    const relatedTablePrimaryKeyIdField = graphql_codegen_hasura_shared_1.getPrimaryKeyIdField(relatedTableNamedType);
    if (!relatedTablePrimaryKeyIdField)
        return;
    graphql_codegen_hasura_shared_1.injectSharedReact({
        contentManager,
        entityName: relatedTableNamedType.name,
        fragmentName,
        trimString: config.trimString,
        primaryKeyIdField: relatedTablePrimaryKeyIdField,
        typescriptCodegenOutputPath: config.typescriptCodegenOutputPath
    });
}
// --------------------------------------
//
function injectEntityQueryTypeScript(fragmentDefinitionNode, contentManager, schemaTypeMap, config) {
    const fragmentName = fragmentDefinitionNode.name.value;
    const fragmentTableName = fragmentDefinitionNode.typeCondition.name.value;
    const relatedTableNamedType = schemaTypeMap[fragmentTableName];
    const relatedTablePrimaryKeyIdField = graphql_codegen_hasura_shared_1.getPrimaryKeyIdField(relatedTableNamedType);
    graphql_codegen_hasura_shared_1.injectFetchReact({
        contentManager,
        entityName: relatedTableNamedType.name,
        fragmentName,
        trimString: config.trimString,
        primaryKeyIdField: relatedTablePrimaryKeyIdField,
        typescriptCodegenOutputPath: config.typescriptCodegenOutputPath
    });
}
// --------------------------------------
//
function injectEntityInsertMutationTypeScript(fragmentDefinitionNode, contentManager, schemaTypeMap, config) {
    const fragmentName = fragmentDefinitionNode.name.value;
    const fragmentTableName = fragmentDefinitionNode.typeCondition.name.value;
    const relatedTableNamedType = schemaTypeMap[fragmentTableName];
    const relatedTablePrimaryKeyIdField = graphql_codegen_hasura_shared_1.getPrimaryKeyIdField(relatedTableNamedType);
    if (!relatedTablePrimaryKeyIdField)
        return;
    graphql_codegen_hasura_shared_1.injectInsertReact({
        contentManager,
        entityName: relatedTableNamedType.name,
        fragmentName,
        trimString: config.trimString,
        primaryKeyIdField: relatedTablePrimaryKeyIdField,
        typescriptCodegenOutputPath: config.typescriptCodegenOutputPath
    });
}
// --------------------------------------
//
function injectEntityUpdateMutationTypeScript(fragmentDefinitionNode, contentManager, schemaTypeMap, config) {
    const fragmentName = fragmentDefinitionNode.name.value;
    const fragmentTableName = fragmentDefinitionNode.typeCondition.name.value;
    const relatedTableNamedType = schemaTypeMap[fragmentTableName];
    const relatedTablePrimaryKeyIdField = graphql_codegen_hasura_shared_1.getPrimaryKeyIdField(relatedTableNamedType);
    if (!relatedTablePrimaryKeyIdField)
        return;
    graphql_codegen_hasura_shared_1.injectUpdateReact({
        contentManager,
        entityName: relatedTableNamedType.name,
        fragmentName,
        trimString: config.trimString,
        primaryKeyIdField: relatedTablePrimaryKeyIdField,
        typescriptCodegenOutputPath: config.typescriptCodegenOutputPath
    });
}
// --------------------------------------
//
function injectEntityDeleteMutationTypeScript(fragmentDefinitionNode, contentManager, schemaTypeMap, config) {
    const fragmentName = fragmentDefinitionNode.name.value;
    const fragmentTableName = fragmentDefinitionNode.typeCondition.name.value;
    const relatedTableNamedType = schemaTypeMap[fragmentTableName];
    const relatedTablePrimaryKeyIdField = graphql_codegen_hasura_shared_1.getPrimaryKeyIdField(relatedTableNamedType);
    if (!relatedTablePrimaryKeyIdField)
        return;
    graphql_codegen_hasura_shared_1.injectDeleteReact({
        contentManager,
        entityName: relatedTableNamedType.name,
        fragmentName,
        trimString: config.trimString,
        primaryKeyIdField: relatedTablePrimaryKeyIdField,
        typescriptCodegenOutputPath: config.typescriptCodegenOutputPath
    });
}
// --------------------------------------
//
//# sourceMappingURL=index.js.map